Learn R Programming

rstyles (version 0.4.0)

generate_item_responses_sml: Internals: simulating responding to item in a 'simultaneous' way

Description

Function generates responses 'simultaneously` with a whole scoring matrix used at once. Only (G)PCM approach is suitable in such a case, because with complicated scoring matrices there is no guarantee that probabilities of responses are increasing along with order of responses (rows) in a scoring matrix. Consequently, no normal ogive models can be used.

Usage

generate_item_responses_sml(theta, scoringMatrix, slopes, intercepts)

Arguments

theta

matrix of latent traits' values

scoringMatrix

matrix describing scoring patterns on each latent trait

slopes

vector of slope parameters of each trait

intercepts

intercept parameters

Value

vector of responses on item

See Also

link{generate_test_responses}, generate_item_responses_sqn, generate_item_responeses_gpcm