# NOT RUN {
# actual expected value of the log-normal distribution with the log scale
# parameters of 3 and 1.5 respectively
lnorm_mean(3, 1.5)
# check:
mean(rlnorm(10^6, 3, 1.5))
# actual standard deviation of the log-normal distribution with the log scale
# parameters of 3 and 1.5 respectively
lnorm_sd(3, 1.5)
# check:
sd(rlnorm(10^6, 3, 1.5))
# what log scale parameters one should use to get actual (exponentiated scale)
# expected value and standard deviaton of the geneareted data of 1 and 0.2
# respectively?
(p <- find_pars_lnorm(1, 0.2))
# check:
lnorm_mean(p[1], p[2])
lnorm_sd(p[1], p[2])
# }
Run the code above in your browser using DataLab