Function generates responses 'simultaneously` with a whole scoring matrix used at once. Only (G)PCM approach is suitable in such a case, because with complicated scoring matrices there is no guarantee that probabilities of responses are increasing along with order of responses (rows) in a scoring matrix. Consequently, no normal ogive models can be used.
generate_item_responses_sml(theta, scoringMatrix, slopes, intercepts)matrix of latent traits' values
matrix describing scoring patterns on each latent trait
vector of slope parameters of each trait
intercept parameters
vector of responses on item
link{generate_test_responses},
generate_item_responses_sqn,
generate_item_responeses_gpcm